==> openshift-model-operatorhub-6.7.2-sources.jar: io/fabric8/openshift/api/model/operatorhub/v1alpha1/StrategyDeploymentSpecBuilder.java <==
package io.fabric8.openshift.api.model.operatorhub.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class StrategyDeploymentSpecBuilder extends StrategyDeploymentSpecFluentImpl<StrategyDeploymentSpecBuilder> implements VisitableBuilder<StrategyDeploymentSpec,StrategyDeploymentSpecBuilder>{
  public StrategyDeploymentSpecBuilder() {
    this(false);
  }
  public StrategyDeploymentSpecBuilder(Boolean validationEnabled) {
    this(new StrategyDeploymentSpec(), validationEnabled);
  }
  public StrategyDeploymentSpecBuilder(StrategyDeploymentSpecFluent<?> fluent) {
    this(fluent, false);
  }
  public StrategyDeploymentSpecBuilder(StrategyDeploymentSpecFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new StrategyDeploymentSpec(), validationEnabled);
  }
  public StrategyDeploymentSpecBuilder(StrategyDeploymentSpecFluent<?> fluent,StrategyDeploymentSpec instance) {
    this(fluent, instance, false);
  }
  public StrategyDeploymentSpecBuilder(StrategyDeploymentSpecFluent<?> fluent,StrategyDeploymentSpec instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withLabel(instance.getLabel());
      fluent.withName(instance.getName());
      fluent.withSpec(instance.getSpec());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public StrategyDeploymentSpecBuilder(StrategyDeploymentSpec instance) {
    this(instance,false);
  }
  public StrategyDeploymentSpecBuilder(StrategyDeploymentSpec instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withLabel(instance.getLabel());
      this.withName(instance.getName());
      this.withSpec(instance.getSpec());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  StrategyDeploymentSpecFluent<?> fluent;
  Boolean validationEnabled;
  public StrategyDeploymentSpec build() {
    StrategyDeploymentSpec buildable = new StrategyDeploymentSpec(fluent.getLabel(),fluent.getName(),fluent.getSpec());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}

==> openshift-model-operatorhub-6.8.1-sources.jar: io/fabric8/openshift/api/model/operatorhub/v1alpha1/StrategyDeploymentSpecBuilder.java <==
package io.fabric8.openshift.api.model.operatorhub.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class StrategyDeploymentSpecBuilder extends StrategyDeploymentSpecFluent<StrategyDeploymentSpecBuilder> implements VisitableBuilder<StrategyDeploymentSpec,StrategyDeploymentSpecBuilder>{
  public StrategyDeploymentSpecBuilder() {
    this(false);
  }
  public StrategyDeploymentSpecBuilder(Boolean validationEnabled) {
    this(new StrategyDeploymentSpec(), validationEnabled);
  }
  public StrategyDeploymentSpecBuilder(StrategyDeploymentSpecFluent<?> fluent) {
    this(fluent, false);
  }
  public StrategyDeploymentSpecBuilder(StrategyDeploymentSpecFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new StrategyDeploymentSpec(), validationEnabled);
  }
  public StrategyDeploymentSpecBuilder(StrategyDeploymentSpecFluent<?> fluent,StrategyDeploymentSpec instance) {
    this(fluent, instance, false);
  }
  public StrategyDeploymentSpecBuilder(StrategyDeploymentSpecFluent<?> fluent,StrategyDeploymentSpec instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new StrategyDeploymentSpec());

    if (instance != null) {
      fluent.withLabel(instance.getLabel());
      fluent.withName(instance.getName());
      fluent.withSpec(instance.getSpec());
      fluent.withLabel(instance.getLabel());
      fluent.withName(instance.getName());
      fluent.withSpec(instance.getSpec());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public StrategyDeploymentSpecBuilder(StrategyDeploymentSpec instance) {
    this(instance,false);
  }
  public StrategyDeploymentSpecBuilder(StrategyDeploymentSpec instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new StrategyDeploymentSpec());

    if (instance != null) {
      this.withLabel(instance.getLabel());
      this.withName(instance.getName());
      this.withSpec(instance.getSpec());
      this.withLabel(instance.getLabel());
      this.withName(instance.getName());
      this.withSpec(instance.getSpec());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  StrategyDeploymentSpecFluent<?> fluent;
  Boolean validationEnabled;
  public StrategyDeploymentSpec build() {
    StrategyDeploymentSpec buildable = new StrategyDeploymentSpec(fluent.getLabel(),fluent.getName(),fluent.getSpec());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
